@@ -1,9 +1,10 @@
 #' Random GeoJSON point
 #'
 #' @export
-#' @param count (integer/numeric) number of Polygons. Default: 1
-#' @param bbox (integer/numeric) bounding box, numeric vector of the form
-#' \code{west, south, east, north}. optional
+#' @param count (integer/numeric) number of points. Default: 1
+#' @param bbox (integer/numeric) lat/long bounding box from which to generate
+#' positions; numeric vector of the form
+#' \code{west (long), south (lat), east (long), north (lat)}. optional
 #' @return GeoJSON; a list with one ore more Points in a FeatureCollection
 #' @examples
 #' geo_point()
@@ -12,6 +13,7 @@
 geo_point <- function(count = 1, bbox = NULL) {
   assert(count, c('numeric', 'integer'))
   assert(bbox, c('numeric', 'integer'))
+  if (!is.null(bbox)) stopifnot(length(bbox) == 4)
 
   features <- list()
   for (i in seq_len(count)) {
