@@ -8,6 +8,7 @@ to_wkt_pt <- function(x, fmt) {
 to_wkt_poly <- function(x, fmt) {
   sprintf(
     "POLYGON ((%s))",
-    paste0(vapply(x, function(z) paste0(format(z, nsmall = fmt, trim = TRUE), collapse = " "), ""), collapse = ", ")
+    paste0(vapply(x, function(z) paste0(format(z, nsmall = fmt, trim = TRUE),
+                                        collapse = " "), ""), collapse = ", ")
   )
 }
